@@ -199,10 +199,9 @@ ucp_cm_ep_client_initial_config_get(ucp_ep_h ucp_ep, unsigned ep_init_flags,
         goto free_ucp_addr;
     }
 
-    /* Update destination MD and RSC indicies in the unpacked address list */
+    /* Update destination MD and RSC indices in the unpacked address list */
     ucp_unpacked_address_for_each(ae, &unpacked_addr) {
         ae->md_index                 = UCP_NULL_RESOURCE;
-        ae->iface_attr.dst_rsc_index = UCP_NULL_RESOURCE;
     }
 
     ucs_assert(unpacked_addr.address_count <= UCP_MAX_RESOURCES);
@@ -409,7 +408,7 @@ static ucs_status_t ucp_cm_ep_init_lanes(ucp_ep_h ep,
             continue;
         }
 
-        status = ucp_wireup_ep_create(ep, NULL, &uct_ep);
+        status = ucp_wireup_ep_create(ep, &uct_ep);
         if (status != UCS_OK) {
             goto out;
         }
@@ -417,7 +416,7 @@ static ucs_status_t ucp_cm_ep_init_lanes(ucp_ep_h ep,
         ucp_ep_set_lane(ep, lane_idx, uct_ep);
 
         UCS_STATIC_BITMAP_SET(tl_bitmap, rsc_idx);
-        if (ucp_ep_config(ep)->p2p_lanes & UCS_BIT(lane_idx)) {
+        if (ucp_ep_is_lane_p2p(ep, lane_idx)) {
             path_index = ucp_ep_get_path_index(ep, lane_idx);
             status     = ucp_wireup_ep_connect(ucp_ep_get_lane(ep, lane_idx), 0,
                                                rsc_idx, path_index, 0, NULL);
@@ -997,7 +996,7 @@ ucs_status_t ucp_ep_client_cm_create_uct_ep(ucp_ep_h ucp_ep)
     cm_lane_params.cm                 = worker->cms[cm_idx].cm;
 
     if (wireup_ep->cm_local_sockaddr.ss_family != 0) {
-        /* user specifed local address */
+        /* user specified local address */
         status = ucs_sockaddr_sizeof((const struct sockaddr*)&wireup_ep->cm_local_sockaddr,
                                      &sockaddr_size);
         if (status != UCS_OK) {
@@ -1415,7 +1414,6 @@ ucp_ep_cm_connect_server_lane(ucp_ep_h ep, uct_listener_h uct_listener,
     ucp_worker_h worker    = ep->worker;
     ucp_lane_index_t lane  = ucp_ep_get_cm_lane(ep);
     unsigned max_num_paths = 0;
-    ucp_rsc_index_t dst_rsc_indices[UCP_MAX_LANES];
     uct_ep_params_t uct_ep_params;
     const ucp_address_entry_t *ae;
     uct_ep_h uct_ep;
@@ -1423,10 +1421,6 @@ ucp_ep_cm_connect_server_lane(ucp_ep_h ep, uct_listener_h uct_listener,
 
     ucs_assert(ucp_ep_get_lane(ep, lane) == NULL);
 
-    ucp_wireup_get_dst_rsc_indices(ep, &ucp_ep_config(ep)->key,
-                                   remote_address, addr_indices,
-                                   dst_rsc_indices);
-
     ucp_unpacked_address_for_each(ae, remote_address) {
         max_num_paths = ucs_max(max_num_paths, ae->dev_num_paths);
     }
@@ -1437,7 +1431,7 @@ ucp_ep_cm_connect_server_lane(ucp_ep_h ep, uct_listener_h uct_listener,
     ucs_assert(max_num_paths > 0);
 
     /* TODO: split CM and wireup lanes */
-    status = ucp_wireup_ep_create(ep, dst_rsc_indices, &uct_ep);
+    status = ucp_wireup_ep_create(ep, &uct_ep);
     if (status != UCS_OK) {
         ucs_warn("server ep %p failed to create wireup CM lane, status %s",
                  ep, ucs_status_string(status));
