@@ -838,9 +838,9 @@ uct_test::entity::entity(const resource& resource, uct_iface_config_t *iface_con
                            uct_worker_create, &m_async.m_async,
                            UCS_THREAD_MODE_SINGLE);
 
-    UCS_TEST_CREATE_HANDLE(uct_md_h, m_md, uct_md_close, uct_md_open,
-                           resource.component, resource.md_name.c_str(),
-                           md_config);
+    UCS_TEST_CREATE_HANDLE_IF_SUPPORTED(uct_md_h, m_md, uct_md_close,
+                                        uct_md_open, resource.component,
+                                        resource.md_name.c_str(), md_config);
 
     m_md_attr.field_mask = UINT64_MAX;
     status               = uct_md_query_v2(m_md, &m_md_attr);
@@ -929,10 +929,12 @@ uct_test::entity::entity(const resource& resource, uct_md_config_t *md_config,
     }
 }
 
-void uct_test::entity::mem_alloc_host(size_t length, unsigned mem_flags,
-                                      uct_allocated_memory_t *mem) const
+void uct_test::entity::mem_alloc(size_t length, unsigned mem_flags,
+                                 uct_allocated_memory_t *mem,
+                                 ucs_memory_type_t mem_type) const
 {
-    void *address             = NULL;
+    void *address   = NULL;
+    uct_md_h uct_md = md();
     ucs_status_t status;
     uct_mem_alloc_params_t params;
 
@@ -942,23 +944,29 @@ void uct_test::entity::mem_alloc_host(size_t length, unsigned mem_flags,
                              UCT_MEM_ALLOC_PARAM_FIELD_NAME;
     params.flags           = mem_flags;
     params.name            = "uct_test";
-    params.mem_type        = UCS_MEMORY_TYPE_HOST;
+    params.mem_type        = mem_type;
     params.address         = address;
 
-    if (md_attr().flags & (UCT_MD_FLAG_ALLOC|UCT_MD_FLAG_REG)) {
+    if ((md_attr().flags & (UCT_MD_FLAG_ALLOC | UCT_MD_FLAG_REG)) &&
+        (mem_type == UCS_MEMORY_TYPE_HOST)) {
         status = uct_iface_mem_alloc(m_iface, length, mem_flags, "uct_test",
                                      mem);
         ASSERT_UCS_OK(status);
     } else {
-        uct_alloc_method_t method = UCT_ALLOC_METHOD_MMAP;
-        status = uct_mem_alloc(length, &method, 1, &params, mem);
+        uct_alloc_method_t alloc_methods[] = {UCT_ALLOC_METHOD_MMAP,
+                                              UCT_ALLOC_METHOD_MD};
+        params.field_mask                 |= UCT_MEM_ALLOC_PARAM_FIELD_MDS;
+        params.mds.mds                     = &uct_md;
+        params.mds.count                   = 1;
+        status = uct_mem_alloc(length, alloc_methods,
+                               ucs_static_array_size(alloc_methods), &params,
+                               mem);
         ASSERT_UCS_OK(status);
-        ucs_assert(mem->memh == UCT_MEM_HANDLE_NULL);
     }
-    ucs_assert(mem->mem_type == UCS_MEMORY_TYPE_HOST);
+    ucs_assert(mem->mem_type == mem_type);
 }
 
-void uct_test::entity::mem_free_host(const uct_allocated_memory_t *mem) const {
+void uct_test::entity::mem_free(const uct_allocated_memory_t *mem) const {
     if (mem->method != UCT_ALLOC_METHOD_LAST) {
         uct_iface_mem_free(mem);
     }
@@ -1407,6 +1415,15 @@ uct_test::mapped_buffer::mapped_buffer(size_t size, uint64_t seed,
                                        const entity &entity, size_t offset,
                                        ucs_memory_type_t mem_type,
                                        unsigned mem_flags) :
+    mapped_buffer(size, entity, offset, mem_type, mem_flags)
+{
+    pattern_fill(seed);
+}
+
+uct_test::mapped_buffer::mapped_buffer(size_t size, 
+                                       const entity &entity, size_t offset,
+                                       ucs_memory_type_t mem_type,
+                                       unsigned mem_flags) :
     m_entity(entity)
 {
     if (size == 0)  {
@@ -1415,8 +1432,8 @@ uct_test::mapped_buffer::mapped_buffer(size_t size, uint64_t seed,
     }
 
     size_t alloc_size = size + offset;
-    if (mem_type == UCS_MEMORY_TYPE_HOST) {
-        m_entity.mem_alloc_host(alloc_size, mem_flags, &m_mem);
+    if ((mem_type == UCS_MEMORY_TYPE_HOST) || (mem_type == UCS_MEMORY_TYPE_RDMA)) {
+        m_entity.mem_alloc(alloc_size, mem_flags, &m_mem, mem_type);
     } else {
         m_mem.method   = UCT_ALLOC_METHOD_LAST;
         m_mem.address  = mem_buffer::allocate(alloc_size, mem_type);
@@ -1429,7 +1446,6 @@ uct_test::mapped_buffer::mapped_buffer(size_t size, uint64_t seed,
 
     m_buf = (char*)m_mem.address + offset;
     m_end = (char*)m_buf         + size;
-    pattern_fill(seed);
     m_iov.buffer = ptr();
     m_iov.length = length();
     m_iov.count  = 1;
@@ -1449,8 +1465,9 @@ uct_test::mapped_buffer::mapped_buffer(mapped_buffer &&other) :
 
 uct_test::mapped_buffer::~mapped_buffer() {
     m_entity.rkey_release(&m_rkey);
-    if (m_mem.mem_type == UCS_MEMORY_TYPE_HOST) {
-        m_entity.mem_free_host(&m_mem);
+    if ((m_mem.mem_type == UCS_MEMORY_TYPE_HOST) ||
+        (m_mem.mem_type == UCS_MEMORY_TYPE_RDMA)) {
+        m_entity.mem_free(&m_mem);
     } else {
         ucs_assert(m_mem.method == UCT_ALLOC_METHOD_LAST);
         m_entity.mem_type_dereg(&m_mem);
@@ -1608,16 +1625,32 @@ void test_uct_iface_attrs::basic_iov_test()
 
     EXPECT_FALSE(max_iov_map.empty());
 
-    if (max_iov_map.find("am")  != max_iov_map.end()) {
+    if (m_e->iface_attr().cap.flags & (UCT_IFACE_FLAG_AM_SHORT |
+                                       UCT_IFACE_FLAG_AM_BCOPY |
+                                       UCT_IFACE_FLAG_AM_ZCOPY)) {
+        EXPECT_NE(max_iov_map.end(), max_iov_map.find("am"));
         EXPECT_EQ(max_iov_map.at("am"), m_e->iface_attr().cap.am.max_iov);
     }
-    if (max_iov_map.find("tag") != max_iov_map.end()) {
+
+    if (m_e->iface_attr().cap.flags & (UCT_IFACE_FLAG_TAG_EAGER_SHORT |
+                                       UCT_IFACE_FLAG_TAG_EAGER_BCOPY|
+                                       UCT_IFACE_FLAG_TAG_EAGER_ZCOPY |
+                                       UCT_IFACE_FLAG_TAG_RNDV_ZCOPY)) {
+        EXPECT_NE(max_iov_map.end(), max_iov_map.find("tag"));
         EXPECT_EQ(max_iov_map.at("tag"), m_e->iface_attr().cap.tag.eager.max_iov);
     }
-    if (max_iov_map.find("put") != max_iov_map.end()) {
+
+    if (m_e->iface_attr().cap.flags & (UCT_IFACE_FLAG_PUT_SHORT |
+                                       UCT_IFACE_FLAG_PUT_BCOPY |
+                                       UCT_IFACE_FLAG_PUT_ZCOPY)) {
+        EXPECT_NE(max_iov_map.end(), max_iov_map.find("put"));
         EXPECT_EQ(max_iov_map.at("put"), m_e->iface_attr().cap.put.max_iov);
     }
-    if (max_iov_map.find("get") != max_iov_map.end()) {
+
+    if (m_e->iface_attr().cap.flags & (UCT_IFACE_FLAG_GET_SHORT |
+                                       UCT_IFACE_FLAG_GET_BCOPY |
+                                       UCT_IFACE_FLAG_GET_ZCOPY)) {
+        EXPECT_NE(max_iov_map.end(), max_iov_map.find("get"));
         EXPECT_EQ(max_iov_map.at("get"), m_e->iface_attr().cap.get.max_iov);
     }
 }
